# coding: utf-8

# flake8: noqa

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from enigma.swagger_client.api.collection_api import CollectionApi
from enigma.swagger_client.api.dataset_api import DatasetApi
from enigma.swagger_client.api.dataset_summary_api import DatasetSummaryApi
from enigma.swagger_client.api.default_api import DefaultApi
from enigma.swagger_client.api.personal_collection_api import PersonalCollectionApi
from enigma.swagger_client.api.policy_api import PolicyApi
from enigma.swagger_client.api.snapshot_api import SnapshotApi
from enigma.swagger_client.api.tags_api import TagsApi
from enigma.swagger_client.api.user_api import UserApi

# import ApiClient
from enigma.swagger_client.api_client import ApiClient
from enigma.swagger_client.configuration import Configuration
# import models into sdk package
from enigma.swagger_client.models.apicollections_parent_collection import ApicollectionsParentCollection
from enigma.swagger_client.models.apicollections_tags import ApicollectionsTags
from enigma.swagger_client.models.apidatasets_dependencies import ApidatasetsDependencies
from enigma.swagger_client.models.apidatasets_source_lag_time import ApidatasetsSourceLagTime
from enigma.swagger_client.models.apidatasetsdataset_idsnapshotssnapshot_id_fields import ApidatasetsdatasetIdsnapshotssnapshotIdFields
from enigma.swagger_client.models.apipersonalcollections_bookmarks import ApipersonalcollectionsBookmarks
from enigma.swagger_client.models.apipersonalcollections_collection import ApipersonalcollectionsCollection
from enigma.swagger_client.models.apipolicies_clause import ApipoliciesClause
from enigma.swagger_client.models.apiusers_profile import ApiusersProfile
from enigma.swagger_client.models.body import Body
from enigma.swagger_client.models.body_1 import Body1
from enigma.swagger_client.models.body_10 import Body10
from enigma.swagger_client.models.body_11 import Body11
from enigma.swagger_client.models.body_12 import Body12
from enigma.swagger_client.models.body_13 import Body13
from enigma.swagger_client.models.body_2 import Body2
from enigma.swagger_client.models.body_3 import Body3
from enigma.swagger_client.models.body_4 import Body4
from enigma.swagger_client.models.body_5 import Body5
from enigma.swagger_client.models.body_6 import Body6
from enigma.swagger_client.models.body_7 import Body7
from enigma.swagger_client.models.body_8 import Body8
from enigma.swagger_client.models.body_9 import Body9
from enigma.swagger_client.models.collection import Collection
from enigma.swagger_client.models.collection_ancestors import CollectionAncestors
from enigma.swagger_client.models.collection_highlights import CollectionHighlights
from enigma.swagger_client.models.dataset import Dataset
from enigma.swagger_client.models.dataset_current_snapshot import DatasetCurrentSnapshot
from enigma.swagger_client.models.dataset_current_snapshot_ingest_status import DatasetCurrentSnapshotIngestStatus
from enigma.swagger_client.models.dataset_current_snapshot_ingest_status_error import DatasetCurrentSnapshotIngestStatusError
from enigma.swagger_client.models.dataset_current_snapshot_table_rows import DatasetCurrentSnapshotTableRows
from enigma.swagger_client.models.dataset_dependencies import DatasetDependencies
from enigma.swagger_client.models.dataset_summary import DatasetSummary
from enigma.swagger_client.models.dataset_summary_data_updated_summary import DatasetSummaryDataUpdatedSummary
from enigma.swagger_client.models.dataset_summary_parent_collection_summary import DatasetSummaryParentCollectionSummary
from enigma.swagger_client.models.dataset_summary_row_count_summary import DatasetSummaryRowCountSummary
from enigma.swagger_client.models.personal_collection import PersonalCollection
from enigma.swagger_client.models.personal_collection_bookmarks import PersonalCollectionBookmarks
from enigma.swagger_client.models.policy import Policy
from enigma.swagger_client.models.policy_clause import PolicyClause
from enigma.swagger_client.models.snapshot import Snapshot
from enigma.swagger_client.models.snapshot_field import SnapshotField
from enigma.swagger_client.models.tag import Tag
from enigma.swagger_client.models.user import User



"""Miscellaneous utility functions."""
import functools


def adjust_kwargs(func, defaults={}, listify=()):
    """Return a function that decorates the kwarg-handling behavior of *func*.

    Arguments in the *defaults* dict will be added to each call when not present.
    Arguments named in the *listify* collection will be converted to list if needed.
    """
    @functools.wraps(func)
    def wrapped(*args, **kwargs):
        for kw, value in defaults.items():
            if kw not in kwargs:
                kwargs[kw] = value
        for name in listify:
            if name in kwargs:
                value = kwargs[name]
                if not isinstance(value, list):
                    kwargs[name] = [value]
        return func(*args, **kwargs)
    return wrapped



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CollectionAncestors(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'description': 'str',
        'description_short': 'str',
        'display_name': 'str',
        'id': 'str',
        'key_value': 'object',
        'modified_at': 'datetime',
        'published': 'bool'
    }

    attribute_map = {
        'created_at': 'created_at',
        'description': 'description',
        'description_short': 'description_short',
        'display_name': 'display_name',
        'id': 'id',
        'key_value': 'key_value',
        'modified_at': 'modified_at',
        'published': 'published'
    }

    def __init__(self, created_at=None, description=None, description_short=None, display_name=None, id=None, key_value=None, modified_at=None, published=None):  # noqa: E501
        """CollectionAncestors - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._description = None
        self._description_short = None
        self._display_name = None
        self._id = None
        self._key_value = None
        self._modified_at = None
        self._published = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if description_short is not None:
            self.description_short = description_short
        if display_name is not None:
            self.display_name = display_name
        self.id = id
        if key_value is not None:
            self.key_value = key_value
        if modified_at is not None:
            self.modified_at = modified_at
        if published is not None:
            self.published = published

    @property
    def created_at(self):
        """Gets the created_at of this CollectionAncestors.  # noqa: E501


        :return: The created_at of this CollectionAncestors.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CollectionAncestors.


        :param created_at: The created_at of this CollectionAncestors.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def description(self):
        """Gets the description of this CollectionAncestors.  # noqa: E501


        :return: The description of this CollectionAncestors.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CollectionAncestors.


        :param description: The description of this CollectionAncestors.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description_short(self):
        """Gets the description_short of this CollectionAncestors.  # noqa: E501


        :return: The description_short of this CollectionAncestors.  # noqa: E501
        :rtype: str
        """
        return self._description_short

    @description_short.setter
    def description_short(self, description_short):
        """Sets the description_short of this CollectionAncestors.


        :param description_short: The description_short of this CollectionAncestors.  # noqa: E501
        :type: str
        """

        self._description_short = description_short

    @property
    def display_name(self):
        """Gets the display_name of this CollectionAncestors.  # noqa: E501


        :return: The display_name of this CollectionAncestors.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CollectionAncestors.


        :param display_name: The display_name of this CollectionAncestors.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def id(self):
        """Gets the id of this CollectionAncestors.  # noqa: E501


        :return: The id of this CollectionAncestors.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CollectionAncestors.


        :param id: The id of this CollectionAncestors.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def key_value(self):
        """Gets the key_value of this CollectionAncestors.  # noqa: E501


        :return: The key_value of this CollectionAncestors.  # noqa: E501
        :rtype: object
        """
        return self._key_value

    @key_value.setter
    def key_value(self, key_value):
        """Sets the key_value of this CollectionAncestors.


        :param key_value: The key_value of this CollectionAncestors.  # noqa: E501
        :type: object
        """

        self._key_value = key_value

    @property
    def modified_at(self):
        """Gets the modified_at of this CollectionAncestors.  # noqa: E501


        :return: The modified_at of this CollectionAncestors.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this CollectionAncestors.


        :param modified_at: The modified_at of this CollectionAncestors.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def published(self):
        """Gets the published of this CollectionAncestors.  # noqa: E501


        :return: The published of this CollectionAncestors.  # noqa: E501
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this CollectionAncestors.


        :param published: The published of this CollectionAncestors.  # noqa: E501
        :type: bool
        """

        self._published = published

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionAncestors):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ApiusersProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'expertise': 'str',
        'subscribed': 'bool'
    }

    attribute_map = {
        'expertise': 'expertise',
        'subscribed': 'subscribed'
    }

    def __init__(self, expertise='null', subscribed=True):  # noqa: E501
        """ApiusersProfile - a model defined in Swagger"""  # noqa: E501

        self._expertise = None
        self._subscribed = None
        self.discriminator = None

        if expertise is not None:
            self.expertise = expertise
        if subscribed is not None:
            self.subscribed = subscribed

    @property
    def expertise(self):
        """Gets the expertise of this ApiusersProfile.  # noqa: E501


        :return: The expertise of this ApiusersProfile.  # noqa: E501
        :rtype: str
        """
        return self._expertise

    @expertise.setter
    def expertise(self, expertise):
        """Sets the expertise of this ApiusersProfile.


        :param expertise: The expertise of this ApiusersProfile.  # noqa: E501
        :type: str
        """
        allowed_values = ["hobbyist", "professional", "student"]  # noqa: E501
        if expertise not in allowed_values:
            raise ValueError(
                "Invalid value for `expertise` ({0}), must be one of {1}"  # noqa: E501
                .format(expertise, allowed_values)
            )

        self._expertise = expertise

    @property
    def subscribed(self):
        """Gets the subscribed of this ApiusersProfile.  # noqa: E501


        :return: The subscribed of this ApiusersProfile.  # noqa: E501
        :rtype: bool
        """
        return self._subscribed

    @subscribed.setter
    def subscribed(self, subscribed):
        """Sets the subscribed of this ApiusersProfile.


        :param subscribed: The subscribed of this ApiusersProfile.  # noqa: E501
        :type: bool
        """

        self._subscribed = subscribed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiusersProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from enigma.swagger_client.models.apidatasets_dependencies import ApidatasetsDependencies  # noqa: F401,E501
from enigma.swagger_client.models.collection_ancestors import CollectionAncestors  # noqa: F401,E501
from enigma.swagger_client.models.collection_highlights import CollectionHighlights  # noqa: F401,E501
from enigma.swagger_client.models.dataset_current_snapshot_ingest_status import DatasetCurrentSnapshotIngestStatus  # noqa: F401,E501
from enigma.swagger_client.models.dataset_current_snapshot_table_rows import DatasetCurrentSnapshotTableRows  # noqa: F401,E501
from enigma.swagger_client.models.snapshot_field import SnapshotField  # noqa: F401,E501


class Snapshot(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'dataset': 'CollectionAncestors',
        'end_date': 'datetime',
        'fields': 'list[SnapshotField]',
        'highlights': 'list[CollectionHighlights]',
        'id': 'str',
        'ingest_schema': 'list[object]',
        'ingest_status': 'DatasetCurrentSnapshotIngestStatus',
        'ingest_url': 'str',
        'parent_snapshot': 'ApidatasetsDependencies',
        'record_start_date': 'datetime',
        'row_count': 'int',
        'size': 'int',
        'start_date': 'datetime',
        'stats': 'object',
        'table_rows': 'DatasetCurrentSnapshotTableRows'
    }

    attribute_map = {
        'created_at': 'created_at',
        'dataset': 'dataset',
        'end_date': 'end_date',
        'fields': 'fields',
        'highlights': 'highlights',
        'id': 'id',
        'ingest_schema': 'ingest_schema',
        'ingest_status': 'ingest_status',
        'ingest_url': 'ingest_url',
        'parent_snapshot': 'parent_snapshot',
        'record_start_date': 'record_start_date',
        'row_count': 'row_count',
        'size': 'size',
        'start_date': 'start_date',
        'stats': 'stats',
        'table_rows': 'table_rows'
    }

    def __init__(self, created_at=None, dataset=None, end_date=None, fields=None, highlights=None, id=None, ingest_schema=None, ingest_status=None, ingest_url=None, parent_snapshot=None, record_start_date=None, row_count=None, size=None, start_date=None, stats=None, table_rows=None):  # noqa: E501
        """Snapshot - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._dataset = None
        self._end_date = None
        self._fields = None
        self._highlights = None
        self._id = None
        self._ingest_schema = None
        self._ingest_status = None
        self._ingest_url = None
        self._parent_snapshot = None
        self._record_start_date = None
        self._row_count = None
        self._size = None
        self._start_date = None
        self._stats = None
        self._table_rows = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if dataset is not None:
            self.dataset = dataset
        if end_date is not None:
            self.end_date = end_date
        if fields is not None:
            self.fields = fields
        if highlights is not None:
            self.highlights = highlights
        if id is not None:
            self.id = id
        if ingest_schema is not None:
            self.ingest_schema = ingest_schema
        if ingest_status is not None:
            self.ingest_status = ingest_status
        if ingest_url is not None:
            self.ingest_url = ingest_url
        if parent_snapshot is not None:
            self.parent_snapshot = parent_snapshot
        if record_start_date is not None:
            self.record_start_date = record_start_date
        if row_count is not None:
            self.row_count = row_count
        if size is not None:
            self.size = size
        if start_date is not None:
            self.start_date = start_date
        if stats is not None:
            self.stats = stats
        if table_rows is not None:
            self.table_rows = table_rows

    @property
    def created_at(self):
        """Gets the created_at of this Snapshot.  # noqa: E501


        :return: The created_at of this Snapshot.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Snapshot.


        :param created_at: The created_at of this Snapshot.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def dataset(self):
        """Gets the dataset of this Snapshot.  # noqa: E501


        :return: The dataset of this Snapshot.  # noqa: E501
        :rtype: CollectionAncestors
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this Snapshot.


        :param dataset: The dataset of this Snapshot.  # noqa: E501
        :type: CollectionAncestors
        """

        self._dataset = dataset

    @property
    def end_date(self):
        """Gets the end_date of this Snapshot.  # noqa: E501


        :return: The end_date of this Snapshot.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Snapshot.


        :param end_date: The end_date of this Snapshot.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def fields(self):
        """Gets the fields of this Snapshot.  # noqa: E501


        :return: The fields of this Snapshot.  # noqa: E501
        :rtype: list[SnapshotField]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this Snapshot.


        :param fields: The fields of this Snapshot.  # noqa: E501
        :type: list[SnapshotField]
        """

        self._fields = fields

    @property
    def highlights(self):
        """Gets the highlights of this Snapshot.  # noqa: E501


        :return: The highlights of this Snapshot.  # noqa: E501
        :rtype: list[CollectionHighlights]
        """
        return self._highlights

    @highlights.setter
    def highlights(self, highlights):
        """Sets the highlights of this Snapshot.


        :param highlights: The highlights of this Snapshot.  # noqa: E501
        :type: list[CollectionHighlights]
        """

        self._highlights = highlights

    @property
    def id(self):
        """Gets the id of this Snapshot.  # noqa: E501


        :return: The id of this Snapshot.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Snapshot.


        :param id: The id of this Snapshot.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ingest_schema(self):
        """Gets the ingest_schema of this Snapshot.  # noqa: E501


        :return: The ingest_schema of this Snapshot.  # noqa: E501
        :rtype: list[object]
        """
        return self._ingest_schema

    @ingest_schema.setter
    def ingest_schema(self, ingest_schema):
        """Sets the ingest_schema of this Snapshot.


        :param ingest_schema: The ingest_schema of this Snapshot.  # noqa: E501
        :type: list[object]
        """

        self._ingest_schema = ingest_schema

    @property
    def ingest_status(self):
        """Gets the ingest_status of this Snapshot.  # noqa: E501


        :return: The ingest_status of this Snapshot.  # noqa: E501
        :rtype: DatasetCurrentSnapshotIngestStatus
        """
        return self._ingest_status

    @ingest_status.setter
    def ingest_status(self, ingest_status):
        """Sets the ingest_status of this Snapshot.


        :param ingest_status: The ingest_status of this Snapshot.  # noqa: E501
        :type: DatasetCurrentSnapshotIngestStatus
        """

        self._ingest_status = ingest_status

    @property
    def ingest_url(self):
        """Gets the ingest_url of this Snapshot.  # noqa: E501


        :return: The ingest_url of this Snapshot.  # noqa: E501
        :rtype: str
        """
        return self._ingest_url

    @ingest_url.setter
    def ingest_url(self, ingest_url):
        """Sets the ingest_url of this Snapshot.


        :param ingest_url: The ingest_url of this Snapshot.  # noqa: E501
        :type: str
        """

        self._ingest_url = ingest_url

    @property
    def parent_snapshot(self):
        """Gets the parent_snapshot of this Snapshot.  # noqa: E501


        :return: The parent_snapshot of this Snapshot.  # noqa: E501
        :rtype: ApidatasetsDependencies
        """
        return self._parent_snapshot

    @parent_snapshot.setter
    def parent_snapshot(self, parent_snapshot):
        """Sets the parent_snapshot of this Snapshot.


        :param parent_snapshot: The parent_snapshot of this Snapshot.  # noqa: E501
        :type: ApidatasetsDependencies
        """

        self._parent_snapshot = parent_snapshot

    @property
    def record_start_date(self):
        """Gets the record_start_date of this Snapshot.  # noqa: E501


        :return: The record_start_date of this Snapshot.  # noqa: E501
        :rtype: datetime
        """
        return self._record_start_date

    @record_start_date.setter
    def record_start_date(self, record_start_date):
        """Sets the record_start_date of this Snapshot.


        :param record_start_date: The record_start_date of this Snapshot.  # noqa: E501
        :type: datetime
        """

        self._record_start_date = record_start_date

    @property
    def row_count(self):
        """Gets the row_count of this Snapshot.  # noqa: E501


        :return: The row_count of this Snapshot.  # noqa: E501
        :rtype: int
        """
        return self._row_count

    @row_count.setter
    def row_count(self, row_count):
        """Sets the row_count of this Snapshot.


        :param row_count: The row_count of this Snapshot.  # noqa: E501
        :type: int
        """

        self._row_count = row_count

    @property
    def size(self):
        """Gets the size of this Snapshot.  # noqa: E501


        :return: The size of this Snapshot.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Snapshot.


        :param size: The size of this Snapshot.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def start_date(self):
        """Gets the start_date of this Snapshot.  # noqa: E501


        :return: The start_date of this Snapshot.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Snapshot.


        :param start_date: The start_date of this Snapshot.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def stats(self):
        """Gets the stats of this Snapshot.  # noqa: E501


        :return: The stats of this Snapshot.  # noqa: E501
        :rtype: object
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this Snapshot.


        :param stats: The stats of this Snapshot.  # noqa: E501
        :type: object
        """

        self._stats = stats

    @property
    def table_rows(self):
        """Gets the table_rows of this Snapshot.  # noqa: E501


        :return: The table_rows of this Snapshot.  # noqa: E501
        :rtype: DatasetCurrentSnapshotTableRows
        """
        return self._table_rows

    @table_rows.setter
    def table_rows(self, table_rows):
        """Sets the table_rows of this Snapshot.


        :param table_rows: The table_rows of this Snapshot.  # noqa: E501
        :type: DatasetCurrentSnapshotTableRows
        """

        self._table_rows = table_rows

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Snapshot):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from enigma.swagger_client.models.dataset_summary_data_updated_summary import DatasetSummaryDataUpdatedSummary  # noqa: F401,E501
from enigma.swagger_client.models.dataset_summary_parent_collection_summary import DatasetSummaryParentCollectionSummary  # noqa: F401,E501
from enigma.swagger_client.models.dataset_summary_row_count_summary import DatasetSummaryRowCountSummary  # noqa: F401,E501


class DatasetSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_updated_summary': 'list[DatasetSummaryDataUpdatedSummary]',
        'parent_collection_summary': 'list[DatasetSummaryParentCollectionSummary]',
        'row_count_summary': 'list[DatasetSummaryRowCountSummary]'
    }

    attribute_map = {
        'data_updated_summary': 'data_updated_summary',
        'parent_collection_summary': 'parent_collection_summary',
        'row_count_summary': 'row_count_summary'
    }

    def __init__(self, data_updated_summary=None, parent_collection_summary=None, row_count_summary=None):  # noqa: E501
        """DatasetSummary - a model defined in Swagger"""  # noqa: E501

        self._data_updated_summary = None
        self._parent_collection_summary = None
        self._row_count_summary = None
        self.discriminator = None

        if data_updated_summary is not None:
            self.data_updated_summary = data_updated_summary
        if parent_collection_summary is not None:
            self.parent_collection_summary = parent_collection_summary
        if row_count_summary is not None:
            self.row_count_summary = row_count_summary

    @property
    def data_updated_summary(self):
        """Gets the data_updated_summary of this DatasetSummary.  # noqa: E501


        :return: The data_updated_summary of this DatasetSummary.  # noqa: E501
        :rtype: list[DatasetSummaryDataUpdatedSummary]
        """
        return self._data_updated_summary

    @data_updated_summary.setter
    def data_updated_summary(self, data_updated_summary):
        """Sets the data_updated_summary of this DatasetSummary.


        :param data_updated_summary: The data_updated_summary of this DatasetSummary.  # noqa: E501
        :type: list[DatasetSummaryDataUpdatedSummary]
        """

        self._data_updated_summary = data_updated_summary

    @property
    def parent_collection_summary(self):
        """Gets the parent_collection_summary of this DatasetSummary.  # noqa: E501


        :return: The parent_collection_summary of this DatasetSummary.  # noqa: E501
        :rtype: list[DatasetSummaryParentCollectionSummary]
        """
        return self._parent_collection_summary

    @parent_collection_summary.setter
    def parent_collection_summary(self, parent_collection_summary):
        """Sets the parent_collection_summary of this DatasetSummary.


        :param parent_collection_summary: The parent_collection_summary of this DatasetSummary.  # noqa: E501
        :type: list[DatasetSummaryParentCollectionSummary]
        """

        self._parent_collection_summary = parent_collection_summary

    @property
    def row_count_summary(self):
        """Gets the row_count_summary of this DatasetSummary.  # noqa: E501


        :return: The row_count_summary of this DatasetSummary.  # noqa: E501
        :rtype: list[DatasetSummaryRowCountSummary]
        """
        return self._row_count_summary

    @row_count_summary.setter
    def row_count_summary(self, row_count_summary):
        """Sets the row_count_summary of this DatasetSummary.


        :param row_count_summary: The row_count_summary of this DatasetSummary.  # noqa: E501
        :type: list[DatasetSummaryRowCountSummary]
        """

        self._row_count_summary = row_count_summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DatasetSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from enigma import models, util


class ApiEndpointGroup:
    """Abstract base class for a wrapped API endpoint group."""

    def __init__(self, client):
        self._model_wrapper = models.ModelWrapper(self._model_cls, client)
        self._client = client
        self._api = self._model_cls._api_cls(client)
        for (func_name, method) in [
            ('get', 'get'),
            ('list', 'list'),
            ('create', 'post'),
            ('update', 'put'),
            ('delete', 'delete'),
        ]:
            api_func_name = getattr(self._model_cls, '_{}_api_name'.format(method))
            if api_func_name:
                api_func = getattr(self._api, api_func_name)
                func = getattr(self, '_make_{}_func'.format(func_name))(api_func)
                setattr(self, func_name, func)

    def _make_get_func(self, get_api):
        return models.wrapped(get_api, self._model_wrapper)

    def _make_list_func(self, list_api):
        return models.range_wrapped(list_api, self._model_wrapper)

    def _make_create_func(self, post_api):
        return models.wrapped(lambda **kwargs: post_api(body=kwargs), self._model_wrapper)

    def _make_update_func(self, put_api):
        return models.wrapped(lambda id, **kwargs: put_api(id, body=kwargs),
                              self._model_wrapper)

    def _make_delete_func(self, delete_api):
        return models.wrapped(delete_api, None)


class UsersApi(ApiEndpointGroup):
    """Convenience wrapper around the generated User API."""
    _model_cls = models.User


class CollectionsApi(ApiEndpointGroup):
    """Convenience wrapper around the generated Collection API."""
    _model_cls = models.Collection

    def __init__(self, client):
        super().__init__(client)
        self.list = util.adjust_kwargs(self.list, listify={'has_tag'})


class DatasetsApi(ApiEndpointGroup):
    """Convenience wrapper around the generated Dataset API."""
    _model_cls = models.Dataset

    def __init__(self, client):
        super().__init__(client)
        self.get = util.adjust_kwargs(self.get, defaults={'include_serialids': True})
        self.list = util.adjust_kwargs(
            self.list,
            defaults={'include_serialids': True},
            listify={'filter', 'has_tag', 'parent_collection_id', 'sort'})


class SnapshotsApi(ApiEndpointGroup):
    """Convenience wrapper around the generated Snapshot API."""
    _model_cls = models.Snapshot

    def __init__(self, client):
        super().__init__(client)
        self.get = util.adjust_kwargs(self.get, {'include_serialids': True})


class TagsApi(ApiEndpointGroup):
    """Convenience wrapper around the generated Tag API."""
    _model_cls = models.Tag



import json
import os

from enigma import swagger_client, models, endpoints
from enigma.models import ApiException


swagger_client.models.SnapshotField.__repr__ = lambda self: '<Field {}>'.format(repr(self.display_name))


class SwaggerClient(swagger_client.ApiClient):
    """An extension to the generated Swagger client that supports Bearer tokens."""

    def __init__(self, enigma_client, path_prefix, *args, **kwargs):
        self.enigma_client = enigma_client
        self.path_prefix = path_prefix.rstrip('/')
        super().__init__(*args, **kwargs)

    def call_api(self, resource_path, method,
                 path_params=None, query_params=None, header_params=None,
                 body=None, post_params=None, files=None, **kwargs):
        if self.path_prefix != '/api':
            if resource_path.startswith('/api'):
                resource_path = resource_path[4:]
            resource_path = self.path_prefix + resource_path
        if header_params is None:
            header_params = {}
        if self.enigma_client.apikey:
            header_params['Authorization'] = 'Bearer ' + self.enigma_client.apikey
        if files and not header_params.get('Content-Type'):
            header_params['Content-Type'] = 'multipart/form-data'
        return super().call_api(resource_path, method, path_params, query_params,
                                header_params, body, post_params, files, **kwargs)


class ApiClient:
    """Entry-point class to all the convenience wrapper APIs."""

    def __init__(self, host, path_prefix='', verify_ssl=True):
        self.apikey = None
        config = swagger_client.Configuration()
        config.host = host.rstrip('/')
        config.verify_ssl = verify_ssl
        self.client = SwaggerClient(self, configuration=config, path_prefix=path_prefix)
        for (name, cls) in [
            ('users', endpoints.UsersApi),
            ('collections', endpoints.CollectionsApi),
            ('datasets', endpoints.DatasetsApi),
            ('snapshots', endpoints.SnapshotsApi),
            ('tags', endpoints.TagsApi),
        ]:
            setattr(self, name, cls(self.client))
        dataset_summary_api = swagger_client.DatasetSummaryApi(self.client)
        self.get_dataset_summary = models.wrapped(dataset_summary_api.api_dataset_summary_get)

    def set_auth(self, apikey=None):
        self.apikey = apikey


class Public(ApiClient):

    def __init__(self):
        super().__init__(host='https://public.enigma.com', path_prefix='/api')
        apikey = os.getenv('ENIGMA_PUBLIC_APIKEY')
        if apikey:
            self.set_auth(apikey)



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PolicyClause(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'collection_id': 'str',
        'dataset_id': 'str',
        'published': 'bool',
        'role': 'str',
        'user_id': 'str'
    }

    attribute_map = {
        'collection_id': 'collection_id',
        'dataset_id': 'dataset_id',
        'published': 'published',
        'role': 'role',
        'user_id': 'user_id'
    }

    def __init__(self, collection_id=None, dataset_id=None, published=False, role='null', user_id='null'):  # noqa: E501
        """PolicyClause - a model defined in Swagger"""  # noqa: E501

        self._collection_id = None
        self._dataset_id = None
        self._published = None
        self._role = None
        self._user_id = None
        self.discriminator = None

        if collection_id is not None:
            self.collection_id = collection_id
        if dataset_id is not None:
            self.dataset_id = dataset_id
        if published is not None:
            self.published = published
        if role is not None:
            self.role = role
        if user_id is not None:
            self.user_id = user_id

    @property
    def collection_id(self):
        """Gets the collection_id of this PolicyClause.  # noqa: E501


        :return: The collection_id of this PolicyClause.  # noqa: E501
        :rtype: str
        """
        return self._collection_id

    @collection_id.setter
    def collection_id(self, collection_id):
        """Sets the collection_id of this PolicyClause.


        :param collection_id: The collection_id of this PolicyClause.  # noqa: E501
        :type: str
        """

        self._collection_id = collection_id

    @property
    def dataset_id(self):
        """Gets the dataset_id of this PolicyClause.  # noqa: E501


        :return: The dataset_id of this PolicyClause.  # noqa: E501
        :rtype: str
        """
        return self._dataset_id

    @dataset_id.setter
    def dataset_id(self, dataset_id):
        """Sets the dataset_id of this PolicyClause.


        :param dataset_id: The dataset_id of this PolicyClause.  # noqa: E501
        :type: str
        """

        self._dataset_id = dataset_id

    @property
    def published(self):
        """Gets the published of this PolicyClause.  # noqa: E501


        :return: The published of this PolicyClause.  # noqa: E501
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this PolicyClause.


        :param published: The published of this PolicyClause.  # noqa: E501
        :type: bool
        """

        self._published = published

    @property
    def role(self):
        """Gets the role of this PolicyClause.  # noqa: E501


        :return: The role of this PolicyClause.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this PolicyClause.


        :param role: The role of this PolicyClause.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def user_id(self):
        """Gets the user_id of this PolicyClause.  # noqa: E501


        :return: The user_id of this PolicyClause.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PolicyClause.


        :param user_id: The user_id of this PolicyClause.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyClause):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from enigma.swagger_client.api_client import ApiClient


class DatasetSummaryApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_dataset_summary_get(self, **kwargs):  # noqa: E501
        """api_dataset_summary_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_dataset_summary_get(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param list[str] filter:
        :param list[str] has_tag:
        :param str in_collection_id:
        :param bool include_serialids:
        :param bool match_metadata:
        :param bool match_rows:
        :param int max_row_count:
        :param int min_row_count:
        :param str mode:
        :param list[str] parent_collection_id:
        :param int phrase_distance:
        :param str query:
        :param int row_limit:
        :param int row_offset:
        :param str row_sort:
        :param list[str] sort:
        :return: DatasetSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_dataset_summary_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api_dataset_summary_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def api_dataset_summary_get_with_http_info(self, **kwargs):  # noqa: E501
        """api_dataset_summary_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_dataset_summary_get_with_http_info(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param list[str] filter:
        :param list[str] has_tag:
        :param str in_collection_id:
        :param bool include_serialids:
        :param bool match_metadata:
        :param bool match_rows:
        :param int max_row_count:
        :param int min_row_count:
        :param str mode:
        :param list[str] parent_collection_id:
        :param int phrase_distance:
        :param str query:
        :param int row_limit:
        :param int row_offset:
        :param str row_sort:
        :param list[str] sort:
        :return: DatasetSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'has_tag', 'in_collection_id', 'include_serialids', 'match_metadata', 'match_rows', 'max_row_count', 'min_row_count', 'mode', 'parent_collection_id', 'phrase_distance', 'query', 'row_limit', 'row_offset', 'row_sort', 'sort']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_dataset_summary_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501
            collection_formats['filter'] = 'multi'  # noqa: E501
        if 'has_tag' in params:
            query_params.append(('has_tag', params['has_tag']))  # noqa: E501
            collection_formats['has_tag'] = 'multi'  # noqa: E501
        if 'in_collection_id' in params:
            query_params.append(('in_collection_id', params['in_collection_id']))  # noqa: E501
        if 'include_serialids' in params:
            query_params.append(('include_serialids', params['include_serialids']))  # noqa: E501
        if 'match_metadata' in params:
            query_params.append(('match_metadata', params['match_metadata']))  # noqa: E501
        if 'match_rows' in params:
            query_params.append(('match_rows', params['match_rows']))  # noqa: E501
        if 'max_row_count' in params:
            query_params.append(('max_row_count', params['max_row_count']))  # noqa: E501
        if 'min_row_count' in params:
            query_params.append(('min_row_count', params['min_row_count']))  # noqa: E501
        if 'mode' in params:
            query_params.append(('mode', params['mode']))  # noqa: E501
        if 'parent_collection_id' in params:
            query_params.append(('parent_collection_id', params['parent_collection_id']))  # noqa: E501
            collection_formats['parent_collection_id'] = 'multi'  # noqa: E501
        if 'phrase_distance' in params:
            query_params.append(('phrase_distance', params['phrase_distance']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'row_limit' in params:
            query_params.append(('row_limit', params['row_limit']))  # noqa: E501
        if 'row_offset' in params:
            query_params.append(('row_offset', params['row_offset']))  # noqa: E501
        if 'row_sort' in params:
            query_params.append(('row_sort', params['row_sort']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
            collection_formats['sort'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/dataset_summary', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DatasetSummary',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from enigma.swagger_client.api.collection_api import CollectionApi
from enigma.swagger_client.api.dataset_api import DatasetApi
from enigma.swagger_client.api.dataset_summary_api import DatasetSummaryApi
from enigma.swagger_client.api.default_api import DefaultApi
from enigma.swagger_client.api.personal_collection_api import PersonalCollectionApi
from enigma.swagger_client.api.policy_api import PolicyApi
from enigma.swagger_client.api.snapshot_api import SnapshotApi
from enigma.swagger_client.api.tags_api import TagsApi
from enigma.swagger_client.api.user_api import UserApi



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from enigma.swagger_client.api_client import ApiClient


class SnapshotApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_snapshots_snapshot_id_delete(self, snapshot_id, **kwargs):  # noqa: E501
        """api_snapshots_snapshot_id_delete  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_snapshots_snapshot_id_delete(snapshot_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str snapshot_id: (required)
        :return: Snapshot
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_snapshots_snapshot_id_delete_with_http_info(snapshot_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_snapshots_snapshot_id_delete_with_http_info(snapshot_id, **kwargs)  # noqa: E501
            return data

    def api_snapshots_snapshot_id_delete_with_http_info(self, snapshot_id, **kwargs):  # noqa: E501
        """api_snapshots_snapshot_id_delete  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_snapshots_snapshot_id_delete_with_http_info(snapshot_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str snapshot_id: (required)
        :return: Snapshot
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['snapshot_id']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_snapshots_snapshot_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'snapshot_id' is set
        if ('snapshot_id' not in params or
                params['snapshot_id'] is None):
            raise ValueError("Missing the required parameter `snapshot_id` when calling `api_snapshots_snapshot_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'snapshot_id' in params:
            path_params['snapshot_id'] = params['snapshot_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/snapshots/{snapshot_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Snapshot',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_snapshots_snapshot_id_get(self, snapshot_id, **kwargs):  # noqa: E501
        """api_snapshots_snapshot_id_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_snapshots_snapshot_id_get(snapshot_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str snapshot_id: (required)
        :param str geo_query:
        :param bool highlight:
        :param bool include_serialids:
        :param int phrase_distance:
        :param str query:
        :param str query_mode:
        :param int row_limit:
        :param int row_offset:
        :param str row_sort:
        :param bool stats:
        :return: Snapshot
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_snapshots_snapshot_id_get_with_http_info(snapshot_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_snapshots_snapshot_id_get_with_http_info(snapshot_id, **kwargs)  # noqa: E501
            return data

    def api_snapshots_snapshot_id_get_with_http_info(self, snapshot_id, **kwargs):  # noqa: E501
        """api_snapshots_snapshot_id_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_snapshots_snapshot_id_get_with_http_info(snapshot_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str snapshot_id: (required)
        :param str geo_query:
        :param bool highlight:
        :param bool include_serialids:
        :param int phrase_distance:
        :param str query:
        :param str query_mode:
        :param int row_limit:
        :param int row_offset:
        :param str row_sort:
        :param bool stats:
        :return: Snapshot
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['snapshot_id', 'geo_query', 'highlight', 'include_serialids', 'phrase_distance', 'query', 'query_mode', 'row_limit', 'row_offset', 'row_sort', 'stats']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_snapshots_snapshot_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'snapshot_id' is set
        if ('snapshot_id' not in params or
                params['snapshot_id'] is None):
            raise ValueError("Missing the required parameter `snapshot_id` when calling `api_snapshots_snapshot_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'snapshot_id' in params:
            path_params['snapshot_id'] = params['snapshot_id']  # noqa: E501

        query_params = []
        if 'geo_query' in params:
            query_params.append(('geo_query', params['geo_query']))  # noqa: E501
        if 'highlight' in params:
            query_params.append(('highlight', params['highlight']))  # noqa: E501
        if 'include_serialids' in params:
            query_params.append(('include_serialids', params['include_serialids']))  # noqa: E501
        if 'phrase_distance' in params:
            query_params.append(('phrase_distance', params['phrase_distance']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'query_mode' in params:
            query_params.append(('query_mode', params['query_mode']))  # noqa: E501
        if 'row_limit' in params:
            query_params.append(('row_limit', params['row_limit']))  # noqa: E501
        if 'row_offset' in params:
            query_params.append(('row_offset', params['row_offset']))  # noqa: E501
        if 'row_sort' in params:
            query_params.append(('row_sort', params['row_sort']))  # noqa: E501
        if 'stats' in params:
            query_params.append(('stats', params['stats']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/snapshots/{snapshot_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Snapshot',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_snapshots_snapshot_id_put(self, snapshot_id, **kwargs):  # noqa: E501
        """api_snapshots_snapshot_id_put  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_snapshots_snapshot_id_put(snapshot_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str snapshot_id: (required)
        :param Body9 body:
        :return: Snapshot
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_snapshots_snapshot_id_put_with_http_info(snapshot_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_snapshots_snapshot_id_put_with_http_info(snapshot_id, **kwargs)  # noqa: E501
            return data

    def api_snapshots_snapshot_id_put_with_http_info(self, snapshot_id, **kwargs):  # noqa: E501
        """api_snapshots_snapshot_id_put  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_snapshots_snapshot_id_put_with_http_info(snapshot_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str snapshot_id: (required)
        :param Body9 body:
        :return: Snapshot
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['snapshot_id', 'body']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_snapshots_snapshot_id_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'snapshot_id' is set
        if ('snapshot_id' not in params or
                params['snapshot_id'] is None):
            raise ValueError("Missing the required parameter `snapshot_id` when calling `api_snapshots_snapshot_id_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'snapshot_id' in params:
            path_params['snapshot_id'] = params['snapshot_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/snapshots/{snapshot_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Snapshot',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from enigma.swagger_client.api_client import ApiClient


class UserApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_users_get(self, **kwargs):  # noqa: E501
        """api_users_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_get(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str range:
        :param str user_email:
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_users_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api_users_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def api_users_get_with_http_info(self, **kwargs):  # noqa: E501
        """api_users_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_get_with_http_info(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str range:
        :param str user_email:
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['range', 'user_email']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_users_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_email' in params:
            query_params.append(('user_email', params['user_email']))  # noqa: E501

        header_params = {}
        if 'range' in params:
            header_params['range'] = params['range']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/users/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[User]',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_users_post(self, **kwargs):  # noqa: E501
        """api_users_post  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_post(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param Body12 body:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_users_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api_users_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def api_users_post_with_http_info(self, **kwargs):  # noqa: E501
        """api_users_post  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_post_with_http_info(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param Body12 body:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_users_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/users/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_users_user_uuid_delete(self, user_uuid, **kwargs):  # noqa: E501
        """api_users_user_uuid_delete  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_user_uuid_delete(user_uuid, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str user_uuid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_users_user_uuid_delete_with_http_info(user_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.api_users_user_uuid_delete_with_http_info(user_uuid, **kwargs)  # noqa: E501
            return data

    def api_users_user_uuid_delete_with_http_info(self, user_uuid, **kwargs):  # noqa: E501
        """api_users_user_uuid_delete  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_user_uuid_delete_with_http_info(user_uuid, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str user_uuid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_uuid']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_users_user_uuid_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_uuid' is set
        if ('user_uuid' not in params or
                params['user_uuid'] is None):
            raise ValueError("Missing the required parameter `user_uuid` when calling `api_users_user_uuid_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_uuid' in params:
            path_params['user_uuid'] = params['user_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/users/{user_uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_users_user_uuid_get(self, user_uuid, **kwargs):  # noqa: E501
        """api_users_user_uuid_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_user_uuid_get(user_uuid, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str user_uuid: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_users_user_uuid_get_with_http_info(user_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.api_users_user_uuid_get_with_http_info(user_uuid, **kwargs)  # noqa: E501
            return data

    def api_users_user_uuid_get_with_http_info(self, user_uuid, **kwargs):  # noqa: E501
        """api_users_user_uuid_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_user_uuid_get_with_http_info(user_uuid, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str user_uuid: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_uuid']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_users_user_uuid_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_uuid' is set
        if ('user_uuid' not in params or
                params['user_uuid'] is None):
            raise ValueError("Missing the required parameter `user_uuid` when calling `api_users_user_uuid_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_uuid' in params:
            path_params['user_uuid'] = params['user_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/users/{user_uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_users_user_uuid_put(self, user_uuid, **kwargs):  # noqa: E501
        """api_users_user_uuid_put  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_user_uuid_put(user_uuid, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str user_uuid: (required)
        :param Body13 body:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_users_user_uuid_put_with_http_info(user_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.api_users_user_uuid_put_with_http_info(user_uuid, **kwargs)  # noqa: E501
            return data

    def api_users_user_uuid_put_with_http_info(self, user_uuid, **kwargs):  # noqa: E501
        """api_users_user_uuid_put  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_users_user_uuid_put_with_http_info(user_uuid, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str user_uuid: (required)
        :param Body13 body:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_uuid', 'body']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_users_user_uuid_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_uuid' is set
        if ('user_uuid' not in params or
                params['user_uuid'] is None):
            raise ValueError("Missing the required parameter `user_uuid` when calling `api_users_user_uuid_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_uuid' in params:
            path_params['user_uuid'] = params['user_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/users/{user_uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from enigma.swagger_client.models.apidatasets_dependencies import ApidatasetsDependencies  # noqa: F401,E501
from enigma.swagger_client.models.apidatasetsdataset_idsnapshotssnapshot_id_fields import ApidatasetsdatasetIdsnapshotssnapshotIdFields  # noqa: F401,E501


class Body9(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_date': 'datetime',
        'fields': 'list[ApidatasetsdatasetIdsnapshotssnapshotIdFields]',
        'id': 'str',
        'parent_snapshot': 'ApidatasetsDependencies',
        'record_start_date': 'datetime',
        'start_date': 'datetime'
    }

    attribute_map = {
        'end_date': 'end_date',
        'fields': 'fields',
        'id': 'id',
        'parent_snapshot': 'parent_snapshot',
        'record_start_date': 'record_start_date',
        'start_date': 'start_date'
    }

    def __init__(self, end_date=None, fields=None, id=None, parent_snapshot=None, record_start_date=None, start_date=None):  # noqa: E501
        """Body9 - a model defined in Swagger"""  # noqa: E501

        self._end_date = None
        self._fields = None
        self._id = None
        self._parent_snapshot = None
        self._record_start_date = None
        self._start_date = None
        self.discriminator = None

        if end_date is not None:
            self.end_date = end_date
        if fields is not None:
            self.fields = fields
        if id is not None:
            self.id = id
        if parent_snapshot is not None:
            self.parent_snapshot = parent_snapshot
        if record_start_date is not None:
            self.record_start_date = record_start_date
        if start_date is not None:
            self.start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Body9.  # noqa: E501


        :return: The end_date of this Body9.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Body9.


        :param end_date: The end_date of this Body9.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def fields(self):
        """Gets the fields of this Body9.  # noqa: E501


        :return: The fields of this Body9.  # noqa: E501
        :rtype: list[ApidatasetsdatasetIdsnapshotssnapshotIdFields]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this Body9.


        :param fields: The fields of this Body9.  # noqa: E501
        :type: list[ApidatasetsdatasetIdsnapshotssnapshotIdFields]
        """

        self._fields = fields

    @property
    def id(self):
        """Gets the id of this Body9.  # noqa: E501


        :return: The id of this Body9.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Body9.


        :param id: The id of this Body9.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def parent_snapshot(self):
        """Gets the parent_snapshot of this Body9.  # noqa: E501


        :return: The parent_snapshot of this Body9.  # noqa: E501
        :rtype: ApidatasetsDependencies
        """
        return self._parent_snapshot

    @parent_snapshot.setter
    def parent_snapshot(self, parent_snapshot):
        """Sets the parent_snapshot of this Body9.


        :param parent_snapshot: The parent_snapshot of this Body9.  # noqa: E501
        :type: ApidatasetsDependencies
        """

        self._parent_snapshot = parent_snapshot

    @property
    def record_start_date(self):
        """Gets the record_start_date of this Body9.  # noqa: E501


        :return: The record_start_date of this Body9.  # noqa: E501
        :rtype: datetime
        """
        return self._record_start_date

    @record_start_date.setter
    def record_start_date(self, record_start_date):
        """Sets the record_start_date of this Body9.


        :param record_start_date: The record_start_date of this Body9.  # noqa: E501
        :type: datetime
        """

        self._record_start_date = record_start_date

    @property
    def start_date(self):
        """Gets the start_date of this Body9.  # noqa: E501


        :return: The start_date of this Body9.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Body9.


        :param start_date: The start_date of this Body9.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Body9):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Utility classes for convenient access of table_rows within a Snapshot."""

class TableView(list):
    """A smart representation of a sampling of rows for a Snapshot."""

    def __init__(self, snapshot, table_rows=None):
        self.snapshot = snapshot
        if table_rows is not None:
            fields_by_name = {field.name: field for field in snapshot.fields}
            self.fields = FieldList(fields_by_name[name] for name in table_rows.fields)
            idx_by_name = {name: i for i, name in enumerate(table_rows.fields)}
            super().__init__(TableRow(row, table_rows.fields, idx_by_name)
                             for row in table_rows.rows)
            self.count = table_rows.count
        else:
            self.fields = FieldList(snapshot.fields)
            self.count = None

    def refresh(self, **kwargs):
        if 'row_limit' not in kwargs:
            kwargs['row_limit'] = 200
        return self.snapshot.refresh(**kwargs).table_rows

    def __repr__(self):
        return '<{} {} snapshot={}>'.format(
            type(self).__name__, hex(id(self)), self.snapshot.id)


class TableRow:
    """A smart representation of one row in a TableView."""

    def __init__(self, values, names, idx_by_name):
        # Arbitrary fields determine attributes, so try to minimize collisions.
        self._enigma_internal_data = (values, names, idx_by_name)

    def __getitem__(self, key):
        (values, _, idx_by_name) = self._enigma_internal_data
        if hasattr(key, 'name') and isinstance(key.name, str):
            key = key.name
        if isinstance(key, str):
            idx = idx_by_name.get(key)
            if idx is None:
                raise KeyError(key)
            key = idx
        if isinstance(key, (int, slice)):
            return values[key]
        msg = '{} indices must not be {}'.format(type(self).__name__, type(key).__name__)
        raise TypeError(msg)

    def __getattr__(self, name):
        try:
            return self[name]
        except KeyError:
            msg = "'{}' object has no attribute '{}'".format(type(self).__name__, name)
            raise AttributeError(msg)

    def __iter__(self):
        (values, _, _) = self._enigma_internal_data
        return iter(values)

    def __len__(self):
        (values, _, _) = self._enigma_internal_data
        return len(values)

    def __repr__(self):
        (values, names, _) = self._enigma_internal_data
        inside = ', '.join('{}: {!r}'.format(*item) for item in zip(names, values))
        return '[{}]'.format(inside)


class FieldList(list):
    """A list of Fields that prints with indices, and supports index() with field names."""

    def index(self, field, start=None, end=None):
        if isinstance(field, str):
            name = field
        elif hasattr(field, 'name'):
            name = field.name
        else:
            raise ValueError('{!r} is not in FieldList'.format(field))
        for idx in range(len(self))[slice(start, end)]:
            if self[idx].name == name:
                return idx
        raise ValueError('{!r} is not in FieldList'.format(field))

    def __contains__(self, field):
        try:
            self.index(field)
            return True
        except ValueError:
            return False

    def __repr__(self):
        inside = ', '.join('{!r}: {!r}'.format(*item) for item in enumerate(self))
        return '[{}]'.format(inside)



import functools
import itertools
import json
import tempfile

from enigma import swagger_client, tableview, util


BOUNDED_PAGE_SIZE = 20
PAGE_SIZE = 50


def wrapped(func, model_wrapper=None):
    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        result = func(*args, **kwargs)
        return model_wrapper(result) if model_wrapper else result
    return wrapper


def range_wrapped(func, model_wrapper):
    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        return ResourceList(func, model_wrapper, *args, **kwargs)
    return wrapper


class ResourceList:
    def __init__(self, api_func, model_wrapper, *args, **kwargs):
        self.bounded = True
        self.func = api_func
        self.wrapper = model_wrapper
        self.args = args
        self.kwargs = kwargs

        self.cache = []
        self.sparse_cache = {}
        self.total = None
        self._fetch_range(0, BOUNDED_PAGE_SIZE)

    def __bool__(self):
        return bool(self.total)

    def __getitem__(self, key):
        cls_name = type(self).__name__
        if isinstance(key, int):
            if key < 0:
                key += self.total
            if not (0 <= key < self.total):
                raise IndexError('{} index out of range'.format(cls_name))
            obj = self._get_cached(key)
            if obj:
                return obj
            start = len(self.cache) if key < len(self.cache) + PAGE_SIZE else key
            self._fetch_range(start, PAGE_SIZE)
            return self[key]

        elif isinstance(key, slice):
            return self._gen_slice(key)

        msg = '{} indices must be integers or slices, not {}'.format(
            cls_name, type(key).__name__)
        raise TypeError(msg)

    def __iter__(self):
        stop = BOUNDED_PAGE_SIZE if self.bounded else None
        return self[:stop]

    def __len__(self):
        if self.bounded:
            return min(BOUNDED_PAGE_SIZE, self.total)
        return self.total

    def __repr__(self):
        if len(self.cache) > 5:
            return '[{}, ...]'.format(', '.join(repr(r) for r in self.cache[:5]))
        else:
            return '[{}]'.format(', '.join(repr(r) for r in self.cache))

    def _gen_slice(self, key):
        """Generate a sequence of objects in this list as specified by the slice *key*."""
        reverse = bool(key.step and key.step < 0)
        for idx in range(self.total)[key.start:key.stop:key.step]:
            obj = self._get_cached(idx)
            if obj:
                yield obj
                continue
            if reverse:
                start = idx - PAGE_SIZE + 1
            elif idx < len(self.cache) + PAGE_SIZE:
                start = len(self.cache)
            else:
                start = idx
            self._fetch_range(start, PAGE_SIZE)
            yield self._get_cached(idx)

    def _get_cached(self, idx):
        """Return an object in the cache for the given *idx*, or None."""
        if idx < len(self.cache):
            return self.cache[idx]
        return self.sparse_cache.get(idx)

    def _fetch_range(self, start, count):
        """Fetch and cache *count* resources beginning at index *start*."""
        self.kwargs['range'] = 'resources={}-{}'.format(start, start + count - 1)
        try:
            objs = self.func(*self.args, **self.kwargs)
        except ApiException as ex:
            if ex.status == 416:
                return
            raise
        objs = [self.wrapper(o) for o in objs]
        headers = self.wrapper.client.last_response.getheaders()
        total = int(headers['content-range'].split('/')[-1])

        clear_cache = (self.total is not None and total != self.total)
        self.total = total
        if clear_cache:
            if start == 0:
                self.cache = objs
                self.sparse_cache = {}
            else:
                self.cache = []
                self.sparse_cache = {i: obj for i, obj in enumerate(objs, start=start)}
        else:
            self._cache_objects(objs, start)

    def _cache_objects(self, objs, start):
        """Insert *objs* into the cache, starting at the index *start*."""
        if start > len(self.cache):
            self.sparse_cache.update(enumerate(objs, start=start))
            return

        # Remove sparse cache objects that would be overwritten by new batch.
        stop = start + len(objs)
        for idx in range(start, stop):
            self.sparse_cache.pop(idx, None)

        # Bulk-resize cache if needed, then copy new objects into cache.
        self.cache.extend([None] * (stop - len(self.cache)))
        self.cache[start:stop] = objs

        # Move any consecutive objects from sparse cache to cache.
        next_indices = itertools.count(len(self.cache))
        sparse_objs = (self.sparse_cache.pop(i, None) for i in next_indices)
        self.cache.extend(itertools.takewhile(bool, sparse_objs))

    def all(self):
        """Set this list to iterate without bounds, and return itself."""
        self.bounded = False
        return self


class ApiException(swagger_client.rest.ApiException):
    def __init__(self, status=None, reason=None, http_resp=None):
        super().__init__(status, reason, http_resp)
        error = self.body
        if isinstance(error, bytes):
            error = error.decode('utf-8')
        self.error_id = None
        self.message = None
        if error:
            error = json.loads(error)
            self.error_id = error['id']
            self.message = error['message']

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({})".format(self.status)
        if self.body:
            error_message += '\n' + self.body
        return error_message

swagger_client.rest.ApiException = ApiException


class ModelWrapper:
    def __init__(self, model_cls, client):
        self.model_cls = model_cls
        self.client = client

    def __call__(self, swagger_obj):
        return self.model_cls(swagger_obj, self.client)


class SDKModel:
    _model_cls = object

    def __init__(self, model, client):
        self._model = model
        self._client = client
        self._api = self._api_cls(client)
        wrapper = ModelWrapper(type(self), client)
        self._get = wrapped(getattr(self._api, self._get_api_name), wrapper)
        self._put = wrapped(getattr(self._api, self._put_api_name), wrapper)
        self._delete = wrapped(getattr(self._api, self._delete_api_name), None)
        for name, wrapper_cls in getattr(self, '_wrapped_attrs', {}).items():
            if isinstance(wrapper_cls, str):
                wrapper_cls = globals()[wrapper_cls]
            value = getattr(model, name, None)
            if value:
                if isinstance(value, list):
                    value = [wrapper_cls(x, client) for x in value]
                else:
                    value = wrapper_cls(value, client)
                object.__setattr__(self, name, value)

    def _as_body(self):
        """Convert a generated model object to a body object accepted by a PUT call."""
        kwargs = {}
        for attr in self._body_cls.attribute_map:
            value = getattr(self, attr)
            if value is not None:
                kwargs[attr] = value
        return self._body_cls(**kwargs)

    def refresh(self, **kwargs):
        return self._get(self.id, **kwargs)

    def save(self):
        """Save the current state of this model as a PUT call."""
        return self._put(self.id, body=self._as_body())

    def update(self, **kwargs):
        """Update this model with the given values, then save it as a PUT call."""
        for key, value in kwargs.items():
            setattr(self, key, value)
        return self.save()

    def delete(self):
        """Delete the resource corresponding to this model, as a DELETE call."""
        return self._delete(self.id)

    def __getattr__(self, name):
        if hasattr(self._model, name):
            return getattr(self._model, name)
        if hasattr(self._model_cls, name):
            if not hasattr(self, '_full_model'):
                self._full_model = self.refresh()
            return getattr(self._full_model, name)
        msg = "'{}' object has no attribute '{}'".format(type(self).__name__, name)
        raise AttributeError(msg)

    def __setattr__(self, name, value):
        if name.startswith('_'):
            object.__setattr__(self, name, value)
        else:
            setattr(self._model, name, value)


class Collection(SDKModel):
    """Convenience wrapper around generated Collection models."""

    _api_cls = swagger_client.CollectionApi
    _body_cls = swagger_client.Body1
    _model_cls = swagger_client.Collection
    _wrapped_attrs = {
        'ancestors': 'Collection',
        'parent_collection': 'Collection',
    }

    _get_api_name = 'api_collections_collection_id_get'
    _list_api_name = 'api_collections_get'
    _post_api_name = 'api_collections_post'
    _put_api_name = 'api_collections_collection_id_put'
    _delete_api_name = 'api_collections_collection_id_delete'

    def _as_body(self):
        """Convert a generated model object to a body object accepted by a PUT call."""
        kwargs = {}
        for attr in self._body_cls.attribute_map:
            value = getattr(self, attr)
            if value is not None or attr == 'parent_collection':
                kwargs[attr] = value
        return kwargs

    def create_collection(self, **kwargs):
        kwargs['parent_collection'] = {'id': self.id}
        return self._client.enigma_client.collections.create(**kwargs)

    def create_dataset(self, **kwargs):
        kwargs['parent_collection'] = {'id': self.id}
        return self._client.enigma_client.datasets.create(**kwargs)

    def child_collections(self, **kwargs):
        kwargs['parent_collection_id'] = self.id
        return self._client.enigma_client.collections.list(**kwargs)

    def child_datasets(self, **kwargs):
        kwargs['parent_collection_id'] = self.id
        return self._client.enigma_client.datasets.list(**kwargs)

    def __repr__(self):
        return '<Collection {}>'.format(repr(self.display_name))


class Dataset(SDKModel):

    _api_cls = swagger_client.DatasetApi
    _body_cls = swagger_client.Body3
    _model_cls = swagger_client.Dataset
    _wrapped_attrs = {
        'ancestors': Collection,
        'current_snapshot': 'Snapshot',
        'parent_collection': Collection,
    }

    _get_api_name = 'api_datasets_dataset_id_get'
    _list_api_name = 'api_datasets_get'
    _post_api_name = 'api_datasets_post'
    _put_api_name = 'api_datasets_dataset_id_put'
    _delete_api_name = 'api_datasets_dataset_id_delete'

    def __init__(self, model, client):
        super().__init__(model, client)
        snap_wrapper = ModelWrapper(Snapshot, client)
        self._post_snap = wrapped(self._api.api_datasets_dataset_id_snapshots_post,
                                  snap_wrapper)
        list_snaps = util.adjust_kwargs(
            self._api.api_datasets_dataset_id_snapshots_get, listify={'sort'})
        self._list_snaps = range_wrapped(list_snaps, snap_wrapper)

    def create_snapshot(self, snap, **kwargs):
        with tempfile.NamedTemporaryFile(mode='w', suffix='.json') as fp:
            json.dump(snap, fp)
            fp.flush()
            return self._post_snap(self.id, fp.name)

    def snapshots(self, **kwargs):
        return self._list_snaps(self.id, **kwargs)

    def __repr__(self):
        return '<Dataset {}>'.format(repr(self.display_name))


class Snapshot(SDKModel):

    _api_cls = swagger_client.SnapshotApi
    _body_cls = swagger_client.Body9
    _model_cls = swagger_client.Snapshot
    _wrapped_attrs = {
        'dataset': Dataset,
        'parent_snapshot': 'Snapshot',
    }

    _get_api_name = 'api_snapshots_snapshot_id_get'
    _list_api_name = None
    _post_api_name = None
    _put_api_name = 'api_snapshots_snapshot_id_put'
    _delete_api_name = 'api_snapshots_snapshot_id_delete'

    def __init__(self, model, client):
        super().__init__(model, client)
        if getattr(model, 'table_rows', None):
            self.table_rows = tableview.TableView(self, model.table_rows)
        else:
            self.table_rows = None

    def get_rows(self, **kwargs):
        """Return refreshed table rows for this snapshot."""
        if kwargs.get('row_limit') is None:
            kwargs['row_limit'] = 200
        return self.refresh(**kwargs).table_rows

    def export_stream(self, **kwargs):
        """Return a streaming urllib3.HTTPResponse object for the requested export."""
        return self._client.call_api(
            '/api/export/{}'.format(self.id),
            'GET',
            query_params=kwargs,
            _return_http_data_only=True,
            _preload_content=False,
        )

    def export_to(self, path_or_file, **kwargs):
        if isinstance(path_or_file, (str, bytes)):
            with open(path_or_file, 'wb') as fp:
                return self.export_to(fp, **kwargs)
        else:
            write = path_or_file.write
            for chunk in self.export_stream(**kwargs):
                write(chunk)

    def export_dataframe(self, **kwargs):
        try:
            import pandas as pd
        except ModuleNotFoundError:
            raise ModuleNotFoundError("pandas is not installed")
        return pd.read_csv(self.export_stream(**kwargs))

    def __repr__(self):
        return '<Snapshot {}>'.format(repr(self.id))


class Tag(SDKModel):
    """Convenience wrapper around generated Tag models."""

    _api_cls = swagger_client.TagsApi
    _model_cls = swagger_client.Tag

    _get_api_name = 'api_tags_tag_id_get'
    _list_api_name = 'api_tags_get'
    _post_api_name = 'api_tags_post'
    _put_api_name = 'api_tags_tag_id_put'
    _delete_api_name = 'api_tags_tag_id_delete'

    def collections(self, **kwargs):
        kwargs['has_tag'] = self.name
        return self._client.enigma_client.collections.list(**kwargs)

    def datasets(self, **kwargs):
        kwargs['has_tag'] = self.name
        return self._client.enigma_client.datasets.list(**kwargs)

    def __repr__(self):
        return '<Tag {}>'.format(repr(self.name))


class User(SDKModel):
    """Convenience wrapper around generated User models."""

    _body_cls = swagger_client.Body13
    _api_cls = swagger_client.UserApi
    _get_api_name = 'api_users_user_uuid_get'
    _list_api_name = 'api_users_get'
    _post_api_name = 'api_users_post'
    _put_api_name = 'api_users_user_uuid_put'
    _delete_api_name = 'api_users_user_uuid_delete'

    def __repr__(self):
        return '<User {!r}>'.format(self.user_email)



# coding: utf-8

"""
    Enigma Public SDK

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import os
from setuptools import setup, find_packages  # noqa: H301

NAME = "enigma-sdk"
VERSION = "1.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    readme = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="Enigma Public SDK",
    url="https://public.enigma.com/",
    author="Enigma",
    author_email="public-support@enigma.com",
    keywords='enigma public data api sdk',
    project_urls={
        'Documentation': 'http://docs.enigma.com/public/public_v20_sdk_about.html',
    },
    packages=find_packages(),
    install_requires=REQUIRES,
    python_requires='~=3.4',
    include_package_data=True,
    long_description=readme,
    long_description_content_type='text/x-rst',
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from enigma.swagger_client.api_client import ApiClient


class PersonalCollectionApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_personal_collections_get(self, **kwargs):  # noqa: E501
        """api_personal_collections_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_get(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str range:
        :return: list[PersonalCollection]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_personal_collections_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api_personal_collections_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def api_personal_collections_get_with_http_info(self, **kwargs):  # noqa: E501
        """api_personal_collections_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_get_with_http_info(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str range:
        :return: list[PersonalCollection]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['range']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_personal_collections_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'range' in params:
            header_params['range'] = params['range']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/personal-collections/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PersonalCollection]',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_personal_collections_personal_collection_id_delete(self, personal_collection_id, **kwargs):  # noqa: E501
        """api_personal_collections_personal_collection_id_delete  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_personal_collection_id_delete(personal_collection_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str personal_collection_id: (required)
        :return: PersonalCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_personal_collections_personal_collection_id_delete_with_http_info(personal_collection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_personal_collections_personal_collection_id_delete_with_http_info(personal_collection_id, **kwargs)  # noqa: E501
            return data

    def api_personal_collections_personal_collection_id_delete_with_http_info(self, personal_collection_id, **kwargs):  # noqa: E501
        """api_personal_collections_personal_collection_id_delete  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_personal_collection_id_delete_with_http_info(personal_collection_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str personal_collection_id: (required)
        :return: PersonalCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['personal_collection_id']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_personal_collections_personal_collection_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'personal_collection_id' is set
        if ('personal_collection_id' not in params or
                params['personal_collection_id'] is None):
            raise ValueError("Missing the required parameter `personal_collection_id` when calling `api_personal_collections_personal_collection_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'personal_collection_id' in params:
            path_params['personal_collection_id'] = params['personal_collection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/personal-collections/{personal_collection_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PersonalCollection',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_personal_collections_personal_collection_id_get(self, personal_collection_id, **kwargs):  # noqa: E501
        """api_personal_collections_personal_collection_id_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_personal_collection_id_get(personal_collection_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str personal_collection_id: (required)
        :return: PersonalCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_personal_collections_personal_collection_id_get_with_http_info(personal_collection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_personal_collections_personal_collection_id_get_with_http_info(personal_collection_id, **kwargs)  # noqa: E501
            return data

    def api_personal_collections_personal_collection_id_get_with_http_info(self, personal_collection_id, **kwargs):  # noqa: E501
        """api_personal_collections_personal_collection_id_get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_personal_collection_id_get_with_http_info(personal_collection_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str personal_collection_id: (required)
        :return: PersonalCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['personal_collection_id']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_personal_collections_personal_collection_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'personal_collection_id' is set
        if ('personal_collection_id' not in params or
                params['personal_collection_id'] is None):
            raise ValueError("Missing the required parameter `personal_collection_id` when calling `api_personal_collections_personal_collection_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'personal_collection_id' in params:
            path_params['personal_collection_id'] = params['personal_collection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/personal-collections/{personal_collection_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PersonalCollection',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_personal_collections_personal_collection_id_put(self, personal_collection_id, **kwargs):  # noqa: E501
        """api_personal_collections_personal_collection_id_put  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_personal_collection_id_put(personal_collection_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str personal_collection_id: (required)
        :param Body6 body:
        :return: PersonalCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_personal_collections_personal_collection_id_put_with_http_info(personal_collection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_personal_collections_personal_collection_id_put_with_http_info(personal_collection_id, **kwargs)  # noqa: E501
            return data

    def api_personal_collections_personal_collection_id_put_with_http_info(self, personal_collection_id, **kwargs):  # noqa: E501
        """api_personal_collections_personal_collection_id_put  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_personal_collection_id_put_with_http_info(personal_collection_id, async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param str personal_collection_id: (required)
        :param Body6 body:
        :return: PersonalCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['personal_collection_id', 'body']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_personal_collections_personal_collection_id_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'personal_collection_id' is set
        if ('personal_collection_id' not in params or
                params['personal_collection_id'] is None):
            raise ValueError("Missing the required parameter `personal_collection_id` when calling `api_personal_collections_personal_collection_id_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'personal_collection_id' in params:
            path_params['personal_collection_id'] = params['personal_collection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/personal-collections/{personal_collection_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PersonalCollection',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_personal_collections_post(self, **kwargs):  # noqa: E501
        """api_personal_collections_post  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_post(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param Body5 body:
        :return: PersonalCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_'):
            return self.api_personal_collections_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api_personal_collections_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def api_personal_collections_post_with_http_info(self, **kwargs):  # noqa: E501
        """api_personal_collections_post  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_=True
        >>> thread = api.api_personal_collections_post_with_http_info(async_=True)
        >>> result = thread.get()

        :param async_ bool
        :param Body5 body:
        :return: PersonalCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_personal_collections_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/personal-collections/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PersonalCollection',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async_'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SnapshotField(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_type': 'str',
        'description': 'str',
        'display_name': 'str',
        'is_serialid': 'bool',
        'name': 'str',
        'visible_by_default': 'bool'
    }

    attribute_map = {
        'data_type': 'data_type',
        'description': 'description',
        'display_name': 'display_name',
        'is_serialid': 'is_serialid',
        'name': 'name',
        'visible_by_default': 'visible_by_default'
    }

    def __init__(self, data_type=None, description=None, display_name=None, is_serialid=False, name=None, visible_by_default=None):  # noqa: E501
        """SnapshotField - a model defined in Swagger"""  # noqa: E501

        self._data_type = None
        self._description = None
        self._display_name = None
        self._is_serialid = None
        self._name = None
        self._visible_by_default = None
        self.discriminator = None

        self.data_type = data_type
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if is_serialid is not None:
            self.is_serialid = is_serialid
        self.name = name
        if visible_by_default is not None:
            self.visible_by_default = visible_by_default

    @property
    def data_type(self):
        """Gets the data_type of this SnapshotField.  # noqa: E501


        :return: The data_type of this SnapshotField.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this SnapshotField.


        :param data_type: The data_type of this SnapshotField.  # noqa: E501
        :type: str
        """
        if data_type is None:
            raise ValueError("Invalid value for `data_type`, must not be `None`")  # noqa: E501
        allowed_values = ["boolean", "datetime", "decimal", "geo_point", "geo_shape", "integer", "string"]  # noqa: E501
        if data_type not in allowed_values:
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}"  # noqa: E501
                .format(data_type, allowed_values)
            )

        self._data_type = data_type

    @property
    def description(self):
        """Gets the description of this SnapshotField.  # noqa: E501


        :return: The description of this SnapshotField.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SnapshotField.


        :param description: The description of this SnapshotField.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self):
        """Gets the display_name of this SnapshotField.  # noqa: E501


        :return: The display_name of this SnapshotField.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this SnapshotField.


        :param display_name: The display_name of this SnapshotField.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def is_serialid(self):
        """Gets the is_serialid of this SnapshotField.  # noqa: E501


        :return: The is_serialid of this SnapshotField.  # noqa: E501
        :rtype: bool
        """
        return self._is_serialid

    @is_serialid.setter
    def is_serialid(self, is_serialid):
        """Sets the is_serialid of this SnapshotField.


        :param is_serialid: The is_serialid of this SnapshotField.  # noqa: E501
        :type: bool
        """

        self._is_serialid = is_serialid

    @property
    def name(self):
        """Gets the name of this SnapshotField.  # noqa: E501


        :return: The name of this SnapshotField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SnapshotField.


        :param name: The name of this SnapshotField.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def visible_by_default(self):
        """Gets the visible_by_default of this SnapshotField.  # noqa: E501


        :return: The visible_by_default of this SnapshotField.  # noqa: E501
        :rtype: bool
        """
        return self._visible_by_default

    @visible_by_default.setter
    def visible_by_default(self, visible_by_default):
        """Sets the visible_by_default of this SnapshotField.


        :param visible_by_default: The visible_by_default of this SnapshotField.  # noqa: E501
        :type: bool
        """

        self._visible_by_default = visible_by_default

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnapshotField):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from enigma.swagger_client.models.apiusers_profile import ApiusersProfile  # noqa: F401,E501


class User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'apikey': 'str',
        'first_name': 'str',
        'id': 'str',
        'is_admin': 'bool',
        'last_name': 'str',
        'password': 'str',
        'password_old': 'str',
        'password_token': 'str',
        'profile': 'ApiusersProfile',
        'roles': 'list[str]',
        'status': 'str',
        'user_email': 'str'
    }

    attribute_map = {
        'apikey': 'apikey',
        'first_name': 'first_name',
        'id': 'id',
        'is_admin': 'is_admin',
        'last_name': 'last_name',
        'password': 'password',
        'password_old': 'password_old',
        'password_token': 'password_token',
        'profile': 'profile',
        'roles': 'roles',
        'status': 'status',
        'user_email': 'user_email'
    }

    def __init__(self, apikey=None, first_name=None, id=None, is_admin=None, last_name=None, password=None, password_old=None, password_token=None, profile=None, roles=None, status=None, user_email=None):  # noqa: E501
        """User - a model defined in Swagger"""  # noqa: E501

        self._apikey = None
        self._first_name = None
        self._id = None
        self._is_admin = None
        self._last_name = None
        self._password = None
        self._password_old = None
        self._password_token = None
        self._profile = None
        self._roles = None
        self._status = None
        self._user_email = None
        self.discriminator = None

        if apikey is not None:
            self.apikey = apikey
        if first_name is not None:
            self.first_name = first_name
        if id is not None:
            self.id = id
        if is_admin is not None:
            self.is_admin = is_admin
        self.last_name = last_name
        if password is not None:
            self.password = password
        if password_old is not None:
            self.password_old = password_old
        if password_token is not None:
            self.password_token = password_token
        if profile is not None:
            self.profile = profile
        if roles is not None:
            self.roles = roles
        if status is not None:
            self.status = status
        if user_email is not None:
            self.user_email = user_email

    @property
    def apikey(self):
        """Gets the apikey of this User.  # noqa: E501


        :return: The apikey of this User.  # noqa: E501
        :rtype: str
        """
        return self._apikey

    @apikey.setter
    def apikey(self, apikey):
        """Sets the apikey of this User.


        :param apikey: The apikey of this User.  # noqa: E501
        :type: str
        """

        self._apikey = apikey

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501


        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.


        :param first_name: The first_name of this User.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def id(self):
        """Gets the id of this User.  # noqa: E501


        :return: The id of this User.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.


        :param id: The id of this User.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_admin(self):
        """Gets the is_admin of this User.  # noqa: E501


        :return: The is_admin of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        """Sets the is_admin of this User.


        :param is_admin: The is_admin of this User.  # noqa: E501
        :type: bool
        """

        self._is_admin = is_admin

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501


        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.


        :param last_name: The last_name of this User.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def password(self):
        """Gets the password of this User.  # noqa: E501


        :return: The password of this User.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this User.


        :param password: The password of this User.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def password_old(self):
        """Gets the password_old of this User.  # noqa: E501


        :return: The password_old of this User.  # noqa: E501
        :rtype: str
        """
        return self._password_old

    @password_old.setter
    def password_old(self, password_old):
        """Sets the password_old of this User.


        :param password_old: The password_old of this User.  # noqa: E501
        :type: str
        """

        self._password_old = password_old

    @property
    def password_token(self):
        """Gets the password_token of this User.  # noqa: E501


        :return: The password_token of this User.  # noqa: E501
        :rtype: str
        """
        return self._password_token

    @password_token.setter
    def password_token(self, password_token):
        """Sets the password_token of this User.


        :param password_token: The password_token of this User.  # noqa: E501
        :type: str
        """

        self._password_token = password_token

    @property
    def profile(self):
        """Gets the profile of this User.  # noqa: E501


        :return: The profile of this User.  # noqa: E501
        :rtype: ApiusersProfile
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this User.


        :param profile: The profile of this User.  # noqa: E501
        :type: ApiusersProfile
        """

        self._profile = profile

    @property
    def roles(self):
        """Gets the roles of this User.  # noqa: E501


        :return: The roles of this User.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this User.


        :param roles: The roles of this User.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def status(self):
        """Gets the status of this User.  # noqa: E501


        :return: The status of this User.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this User.


        :param status: The status of this User.  # noqa: E501
        :type: str
        """
        allowed_values = ["confirmed", "deleted", "unconfirmed"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def user_email(self):
        """Gets the user_email of this User.  # noqa: E501


        :return: The user_email of this User.  # noqa: E501
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email):
        """Sets the user_email of this User.


        :param user_email: The user_email of this User.  # noqa: E501
        :type: str
        """

        self._user_email = user_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from enigma.swagger_client.models.apicollections_parent_collection import ApicollectionsParentCollection  # noqa: F401,E501
from enigma.swagger_client.models.apicollections_tags import ApicollectionsTags  # noqa: F401,E501
from enigma.swagger_client.models.apidatasets_dependencies import ApidatasetsDependencies  # noqa: F401,E501
from enigma.swagger_client.models.apidatasets_source_lag_time import ApidatasetsSourceLagTime  # noqa: F401,E501


class Body2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'citation': 'str',
        'dependencies': 'list[ApidatasetsDependencies]',
        'derivatives': 'list[ApidatasetsDependencies]',
        'description': 'str',
        'description_short': 'str',
        'display_name': 'str',
        'extraction_type': 'str',
        'key_value': 'object',
        'one_time_ingestion': 'bool',
        'parent_collection': 'ApicollectionsParentCollection',
        'published': 'bool',
        'resource_owner': 'str',
        'resource_owner_contact': 'str',
        'source_description': 'str',
        'source_lag_time': 'ApidatasetsSourceLagTime',
        'source_type': 'str',
        'source_update_schedule': 'ApidatasetsSourceLagTime',
        'tags': 'list[ApicollectionsTags]',
        'technical_owner': 'str',
        'technical_owner_contact': 'str',
        'terms_of_service': 'str'
    }

    attribute_map = {
        'citation': 'citation',
        'dependencies': 'dependencies',
        'derivatives': 'derivatives',
        'description': 'description',
        'description_short': 'description_short',
        'display_name': 'display_name',
        'extraction_type': 'extraction_type',
        'key_value': 'key_value',
        'one_time_ingestion': 'one_time_ingestion',
        'parent_collection': 'parent_collection',
        'published': 'published',
        'resource_owner': 'resource_owner',
        'resource_owner_contact': 'resource_owner_contact',
        'source_description': 'source_description',
        'source_lag_time': 'source_lag_time',
        'source_type': 'source_type',
        'source_update_schedule': 'source_update_schedule',
        'tags': 'tags',
        'technical_owner': 'technical_owner',
        'technical_owner_contact': 'technical_owner_contact',
        'terms_of_service': 'terms_of_service'
    }

    def __init__(self, citation='', dependencies=None, derivatives=None, description='', description_short='', display_name=None, extraction_type=None, key_value=None, one_time_ingestion=None, parent_collection=None, published=False, resource_owner=None, resource_owner_contact=None, source_description=None, source_lag_time=None, source_type=None, source_update_schedule=None, tags=None, technical_owner=None, technical_owner_contact=None, terms_of_service=None):  # noqa: E501
        """Body2 - a model defined in Swagger"""  # noqa: E501

        self._citation = None
        self._dependencies = None
        self._derivatives = None
        self._description = None
        self._description_short = None
        self._display_name = None
        self._extraction_type = None
        self._key_value = None
        self._one_time_ingestion = None
        self._parent_collection = None
        self._published = None
        self._resource_owner = None
        self._resource_owner_contact = None
        self._source_description = None
        self._source_lag_time = None
        self._source_type = None
        self._source_update_schedule = None
        self._tags = None
        self._technical_owner = None
        self._technical_owner_contact = None
        self._terms_of_service = None
        self.discriminator = None

        if citation is not None:
            self.citation = citation
        if dependencies is not None:
            self.dependencies = dependencies
        if derivatives is not None:
            self.derivatives = derivatives
        if description is not None:
            self.description = description
        if description_short is not None:
            self.description_short = description_short
        self.display_name = display_name
        if extraction_type is not None:
            self.extraction_type = extraction_type
        if key_value is not None:
            self.key_value = key_value
        if one_time_ingestion is not None:
            self.one_time_ingestion = one_time_ingestion
        if parent_collection is not None:
            self.parent_collection = parent_collection
        if published is not None:
            self.published = published
        if resource_owner is not None:
            self.resource_owner = resource_owner
        if resource_owner_contact is not None:
            self.resource_owner_contact = resource_owner_contact
        if source_description is not None:
            self.source_description = source_description
        if source_lag_time is not None:
            self.source_lag_time = source_lag_time
        if source_type is not None:
            self.source_type = source_type
        if source_update_schedule is not None:
            self.source_update_schedule = source_update_schedule
        if tags is not None:
            self.tags = tags
        if technical_owner is not None:
            self.technical_owner = technical_owner
        if technical_owner_contact is not None:
            self.technical_owner_contact = technical_owner_contact
        if terms_of_service is not None:
            self.terms_of_service = terms_of_service

    @property
    def citation(self):
        """Gets the citation of this Body2.  # noqa: E501


        :return: The citation of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._citation

    @citation.setter
    def citation(self, citation):
        """Sets the citation of this Body2.


        :param citation: The citation of this Body2.  # noqa: E501
        :type: str
        """

        self._citation = citation

    @property
    def dependencies(self):
        """Gets the dependencies of this Body2.  # noqa: E501


        :return: The dependencies of this Body2.  # noqa: E501
        :rtype: list[ApidatasetsDependencies]
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this Body2.


        :param dependencies: The dependencies of this Body2.  # noqa: E501
        :type: list[ApidatasetsDependencies]
        """

        self._dependencies = dependencies

    @property
    def derivatives(self):
        """Gets the derivatives of this Body2.  # noqa: E501


        :return: The derivatives of this Body2.  # noqa: E501
        :rtype: list[ApidatasetsDependencies]
        """
        return self._derivatives

    @derivatives.setter
    def derivatives(self, derivatives):
        """Sets the derivatives of this Body2.


        :param derivatives: The derivatives of this Body2.  # noqa: E501
        :type: list[ApidatasetsDependencies]
        """

        self._derivatives = derivatives

    @property
    def description(self):
        """Gets the description of this Body2.  # noqa: E501


        :return: The description of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Body2.


        :param description: The description of this Body2.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description_short(self):
        """Gets the description_short of this Body2.  # noqa: E501


        :return: The description_short of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._description_short

    @description_short.setter
    def description_short(self, description_short):
        """Sets the description_short of this Body2.


        :param description_short: The description_short of this Body2.  # noqa: E501
        :type: str
        """

        self._description_short = description_short

    @property
    def display_name(self):
        """Gets the display_name of this Body2.  # noqa: E501


        :return: The display_name of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Body2.


        :param display_name: The display_name of this Body2.  # noqa: E501
        :type: str
        """
        if display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def extraction_type(self):
        """Gets the extraction_type of this Body2.  # noqa: E501


        :return: The extraction_type of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._extraction_type

    @extraction_type.setter
    def extraction_type(self, extraction_type):
        """Sets the extraction_type of this Body2.


        :param extraction_type: The extraction_type of this Body2.  # noqa: E501
        :type: str
        """

        self._extraction_type = extraction_type

    @property
    def key_value(self):
        """Gets the key_value of this Body2.  # noqa: E501


        :return: The key_value of this Body2.  # noqa: E501
        :rtype: object
        """
        return self._key_value

    @key_value.setter
    def key_value(self, key_value):
        """Sets the key_value of this Body2.


        :param key_value: The key_value of this Body2.  # noqa: E501
        :type: object
        """

        self._key_value = key_value

    @property
    def one_time_ingestion(self):
        """Gets the one_time_ingestion of this Body2.  # noqa: E501


        :return: The one_time_ingestion of this Body2.  # noqa: E501
        :rtype: bool
        """
        return self._one_time_ingestion

    @one_time_ingestion.setter
    def one_time_ingestion(self, one_time_ingestion):
        """Sets the one_time_ingestion of this Body2.


        :param one_time_ingestion: The one_time_ingestion of this Body2.  # noqa: E501
        :type: bool
        """

        self._one_time_ingestion = one_time_ingestion

    @property
    def parent_collection(self):
        """Gets the parent_collection of this Body2.  # noqa: E501


        :return: The parent_collection of this Body2.  # noqa: E501
        :rtype: ApicollectionsParentCollection
        """
        return self._parent_collection

    @parent_collection.setter
    def parent_collection(self, parent_collection):
        """Sets the parent_collection of this Body2.


        :param parent_collection: The parent_collection of this Body2.  # noqa: E501
        :type: ApicollectionsParentCollection
        """

        self._parent_collection = parent_collection

    @property
    def published(self):
        """Gets the published of this Body2.  # noqa: E501


        :return: The published of this Body2.  # noqa: E501
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this Body2.


        :param published: The published of this Body2.  # noqa: E501
        :type: bool
        """

        self._published = published

    @property
    def resource_owner(self):
        """Gets the resource_owner of this Body2.  # noqa: E501


        :return: The resource_owner of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._resource_owner

    @resource_owner.setter
    def resource_owner(self, resource_owner):
        """Sets the resource_owner of this Body2.


        :param resource_owner: The resource_owner of this Body2.  # noqa: E501
        :type: str
        """

        self._resource_owner = resource_owner

    @property
    def resource_owner_contact(self):
        """Gets the resource_owner_contact of this Body2.  # noqa: E501


        :return: The resource_owner_contact of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._resource_owner_contact

    @resource_owner_contact.setter
    def resource_owner_contact(self, resource_owner_contact):
        """Sets the resource_owner_contact of this Body2.


        :param resource_owner_contact: The resource_owner_contact of this Body2.  # noqa: E501
        :type: str
        """

        self._resource_owner_contact = resource_owner_contact

    @property
    def source_description(self):
        """Gets the source_description of this Body2.  # noqa: E501


        :return: The source_description of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._source_description

    @source_description.setter
    def source_description(self, source_description):
        """Sets the source_description of this Body2.


        :param source_description: The source_description of this Body2.  # noqa: E501
        :type: str
        """

        self._source_description = source_description

    @property
    def source_lag_time(self):
        """Gets the source_lag_time of this Body2.  # noqa: E501


        :return: The source_lag_time of this Body2.  # noqa: E501
        :rtype: ApidatasetsSourceLagTime
        """
        return self._source_lag_time

    @source_lag_time.setter
    def source_lag_time(self, source_lag_time):
        """Sets the source_lag_time of this Body2.


        :param source_lag_time: The source_lag_time of this Body2.  # noqa: E501
        :type: ApidatasetsSourceLagTime
        """

        self._source_lag_time = source_lag_time

    @property
    def source_type(self):
        """Gets the source_type of this Body2.  # noqa: E501


        :return: The source_type of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this Body2.


        :param source_type: The source_type of this Body2.  # noqa: E501
        :type: str
        """

        self._source_type = source_type

    @property
    def source_update_schedule(self):
        """Gets the source_update_schedule of this Body2.  # noqa: E501


        :return: The source_update_schedule of this Body2.  # noqa: E501
        :rtype: ApidatasetsSourceLagTime
        """
        return self._source_update_schedule

    @source_update_schedule.setter
    def source_update_schedule(self, source_update_schedule):
        """Sets the source_update_schedule of this Body2.


        :param source_update_schedule: The source_update_schedule of this Body2.  # noqa: E501
        :type: ApidatasetsSourceLagTime
        """

        self._source_update_schedule = source_update_schedule

    @property
    def tags(self):
        """Gets the tags of this Body2.  # noqa: E501


        :return: The tags of this Body2.  # noqa: E501
        :rtype: list[ApicollectionsTags]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Body2.


        :param tags: The tags of this Body2.  # noqa: E501
        :type: list[ApicollectionsTags]
        """

        self._tags = tags

    @property
    def technical_owner(self):
        """Gets the technical_owner of this Body2.  # noqa: E501


        :return: The technical_owner of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._technical_owner

    @technical_owner.setter
    def technical_owner(self, technical_owner):
        """Sets the technical_owner of this Body2.


        :param technical_owner: The technical_owner of this Body2.  # noqa: E501
        :type: str
        """

        self._technical_owner = technical_owner

    @property
    def technical_owner_contact(self):
        """Gets the technical_owner_contact of this Body2.  # noqa: E501


        :return: The technical_owner_contact of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._technical_owner_contact

    @technical_owner_contact.setter
    def technical_owner_contact(self, technical_owner_contact):
        """Sets the technical_owner_contact of this Body2.


        :param technical_owner_contact: The technical_owner_contact of this Body2.  # noqa: E501
        :type: str
        """

        self._technical_owner_contact = technical_owner_contact

    @property
    def terms_of_service(self):
        """Gets the terms_of_service of this Body2.  # noqa: E501


        :return: The terms_of_service of this Body2.  # noqa: E501
        :rtype: str
        """
        return self._terms_of_service

    @terms_of_service.setter
    def terms_of_service(self, terms_of_service):
        """Sets the terms_of_service of this Body2.


        :param terms_of_service: The terms_of_service of this Body2.  # noqa: E501
        :type: str
        """

        self._terms_of_service = terms_of_service

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Body2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
